Class: BlueFactory::Server

Inherits:
Sinatra::Base
  • Object
show all
Defined in:
lib/blue_factory/server.rb

Overview

Sinatra server implementing the required feed generator endpoints. Usually you will only interact with it in order to start the server in a startup script.

Examples:

Starting locally during development

BlueFactory::Server.run!

Starting from Rack config config.ru in production

run BlueFactory::Server

Constant Summary collapse

@@config_checked =
false

Class Method Summary collapse

Class Method Details

.run!(options = {}, &block) ⇒ Object

Run the Sinatra app as a self-hosted server. See Sinatra::Base.run!.



32
33
34
35
# File 'lib/blue_factory/server.rb', line 32

def self.run!(options = {}, &block)
  verify_config
  super
end