Class: BlueFactory::Server
- Inherits:
-
Sinatra::Base
- Object
- Sinatra::Base
- BlueFactory::Server
- Defined in:
- lib/blue_factory/server.rb
Overview
Sinatra server implementing the required feed generator endpoints. Usually you will only interact with it in order to start the server in a startup script.
Constant Summary collapse
- @@config_checked =
false
Class Method Summary collapse
-
.run!(options = {}, &block) ⇒ Object
Run the Sinatra app as a self-hosted server.
Class Method Details
.run!(options = {}, &block) ⇒ Object
Run the Sinatra app as a self-hosted server. See Sinatra::Base.run!.
32 33 34 35 |
# File 'lib/blue_factory/server.rb', line 32 def self.run!( = {}, &block) verify_config super end |